@@ -1,5 +1,6 @@
 from django.db import models
 from django.core.exceptions import ValidationError
+from django.utils import six
 
 from collections import defaultdict
 import datetime
@@ -14,12 +15,11 @@ COLUMN_TYPES = defaultdict(lambda:"char(20)")
 COLUMN_TYPES["django.db.backends.postgresql_psycopg2"] = "interval"
 COLUMN_TYPES["django.contrib.gis.db.backends.postgis"] = "interval"
 
-class TimedeltaField(models.Field):
+class TimedeltaField(six.with_metaclass(models.SubfieldBase, models.Field)):
     """
     Store a datetime.timedelta as an INTERVAL in postgres, or a 
     CHAR(20) in other database backends.
     """
-    __metaclass__ = models.SubfieldBase
     _south_introspects = True
     
     description = "A datetime.timedelta object"
@@ -44,7 +44,7 @@ class TimedeltaField(models.Field):
     def get_prep_value(self, value):
         if self.null and value == "":
             return None
-        if (value is None) or isinstance(value, (str, unicode)):
+        if (value is None) or isinstance(value, six.string_types):
             return value
         return str(value).replace(',', '')
         
